#include "WiFi.h"
#include <WebServer.h>

WebServer server(80); //Default port for the ESP32 server relationship

const int DIR1 = 26; //33; 
const int PWM1_PIN = 25;//32;
const int DIR2 = 33; 
const int PWM2_PIN = 32;
//Adding the html page to the Arduino code 
void Homepage() {
  String page= "<!DOCTYPE html>";
page += "<html lang='fr'>";
page += "<head>";
page += "<p>Jean-Come Picot- FabAcademy 2024</p>";
page += "<title>Robot Control</title>";
page += "<style>";
page += "body { font-family: Arial, sans-serif; text-align: center; background-color: black; color: white; }";
page += ".button { background-color: #FF0000; border: none; color: white; padding: 30px 50px;";
page += "text-decoration: none; display: inline-block; font-size: 36px; margin: 10px 20px; cursor: pointer;";
page += "border-radius: 50%; } /* Bouton rond */";
page += ".container { display: flex; flex-direction: column; align-items: center; margin-top: 100px; }";
page += ".button-group { display: flex; justify-content: center; }";
page += "#stopBtn { background-color: #FF0000; border: none; color: white; padding: 30px 50px;";
page += "text-decoration: none; display: inline-block; font-size: 36px; margin: 50px 20px; cursor: pointer; } /* Bouton STOP */";
page += "</style>";
page += "</head>";
page += "<body>";
page += "<div class='container'>";
page += "<h1>Robot remote control</h1>";
page += "<h3> Click on one of the arrows to move the robot forward</h3>";
page += "<a href='/front'><button class='button' id='goBtn'>&#8593;</button></a>"; // Flèche vers le haut
page += "<div class='button-group'>";
page += "<a href='/left'><button class='button' id='leftBtn'>&#8592;</button></a>"; // Flèche vers la gauche
page += "<a href='/right'><button class='button' id='rightBtn'>&#8594;</button></a>"; // Flèche vers la droite
page += "</div>";
page += "<a href='/stop'><button id='stopBtn'>STOP</button></a>"; // Bouton STOP
page += "</div>";
page += "</body>";
page += "</html>";
  server.setContentLength(page.length()); //This allows the ESP32 to know the length of the website, which allows faster communication
  server.send(200, "text/html", page); // Enables data to be sent
} 

void NotFound() // Function that writes to the user "404 Not found" if a page is unknown
{
    server.send(404, "text/plain", "404: Not found");
}

void front() //To get both wheels moving at the same speed
{
    digitalWrite(DIR1, HIGH);
    digitalWrite(DIR2, HIGH);
    analogWrite(PWM1_PIN, 100);
    analogWrite(PWM2_PIN, 100);
    server.sendHeader("Location","/"); // This then links to the home page 
    server.send(303); // Command that tells the server it is doing a redirect 
}

void stop() //Stop the two wheels
{
    digitalWrite(DIR1, HIGH);
    digitalWrite(DIR2, HIGH);
    analogWrite(PWM1_PIN, 0);
    analogWrite(PWM2_PIN, 0);
    server.sendHeader("Location","/"); // This then links to the home page 
    server.send(303); // Command that tells the server it is doing a redirect 
}

void left() //Turn the left wheel only
{
    digitalWrite(DIR1, HIGH);
    digitalWrite(DIR2, HIGH);
    analogWrite(PWM1_PIN, 50);
    analogWrite(PWM2_PIN, 0);
    server.sendHeader("Location","/"); // This then links to the home page 
    server.send(303); // Command that tells the server it is doing a redirect 
}

void right() //Only move the right-hand wheel forward
{
    digitalWrite(DIR1, HIGH);
    digitalWrite(DIR2, HIGH);
    analogWrite(PWM1_PIN, 0);
    analogWrite(PWM2_PIN, 50);
    server.sendHeader("Location","/"); // This then links to the home page 
    server.send(303); // Command that tells the server it is doing a redirect 
}

void setup()
{
  Serial.begin(115200); //Baud rate of 115200 for the esp32, not 9600 like the arduino boards
  WiFi.softAP("Robot_JC", "123456789");//Create the esp32 wifi network by choosing the network name and code
  delay(1000); // Delay 1s
  Serial.println("\n"); // Make a line break in the serial monitor
//Declares pine trees
  pinMode(DIR1, OUTPUT);//direction motor1
  pinMode(PWM1_PIN, OUTPUT);//pwm motor 1
  pinMode(DIR2, OUTPUT);//direction motor 2
  pinMode(PWM2_PIN, OUTPUT);//speed motor 2

  //Displays the IP address of esp32
  Serial.print("Host IP: ");
  Serial.println(WiFi.softAPIP());

//Links the keys activated on the web page to the arduino code functions 
  server.on("/", Homepage); // When the server is on "/" then do the homepage function
  server.on("/front", front); // When the server is on "/go" then do the go function
  server.on("/left", left); // When the server is on "/left" then do the left function
  server.on("/right", right); // When the server is on "/right" then do the right function
  server.on("/stop", stop); // When the server is on "/stop" then do the stop function
  server.onNotFound(NotFound); // When the server is not found then do the NotFound function
  server.begin(); // Start the server

  Serial.println("Active web server!"); // Print on the serial monitor "Active web server!"

}

void loop()
{
  server.handleClient(); // Manage the user who is connected to the server
}